/***********************************************************************
*
* Copyright (c) 2021-2022 Barbara Geller and Ansel Sermersheim
*
* This example is free software, released under the BSD 2-Clause license.
* For license details refer to LICENSE provided with this project.
*
* CopperSpice is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
*
* https://opensource.org/licenses/BSD-2-Clause
*
***********************************************************************/

#include <QtCore>
#include <QtGui>

class MainWindow : public QWidget
{
 public:
   MainWindow();

 private:
   void setItem();
   void setText();

   QLineEdit *item_text;
   QLineEdit *str_text;
};

MainWindow::MainWindow()
{
   setMinimumSize(700, 350);

   QPushButton *item_pb = new QPushButton("Item");
   item_text = new QLineEdit();

   QPushButton *str_pb = new QPushButton("String");
   str_text = new QLineEdit();

   QPushButton *close_pb = new QPushButton();
   close_pb->setText("Close");

   QGridLayout *grid1 = new QGridLayout();
   grid1->setContentsMargins(75, 45, 75, 25);
   grid1->setHorizontalSpacing(20);
   grid1->setVerticalSpacing(45);

   grid1->addWidget(item_pb, 0, 0);
   grid1->addWidget(item_text, 0, 1);

   grid1->addWidget(str_pb, 1, 0);
   grid1->addWidget(str_text, 1, 1);

   QHBoxLayout *layout1 = new QHBoxLayout();
   layout1->addStretch();
   layout1->addWidget(close_pb);
   layout1->addStretch();

   QVBoxLayout *layoutMain = new QVBoxLayout(this);
   layoutMain->addLayout(grid1);
   layoutMain->addSpacing(75);
   layoutMain->addLayout(layout1);

   connect(item_pb, &QPushButton::clicked, this, &MainWindow::setItem);
   connect(str_pb,  &QPushButton::clicked, this, &MainWindow::setText);

   connect(close_pb, &QPushButton::clicked, this, &QWidget::close);
}

void MainWindow::setItem()
{
   QStringList itemList;
   itemList << "Spring" << "Summer" << "Fall" << "Winter";

   bool ok;

   QString data = QInputDialog::getItem(this, "Item",
         "Select a Season:", itemList, 0, false, &ok);

   if (ok && ! data.isEmpty()) {
      item_text->setText(data);
   }
}

void MainWindow::setText()
{
   bool ok;

   QString data = QInputDialog::getText(this, "String",
         "User name:", QLineEdit::Normal, QDir::home().dirName(), &ok);

   if (ok && ! data.isEmpty()) {
      str_text->setText(data);
   }
}

int main(int argc, char *argv[])
{
   QApplication app(argc, argv);

   MainWindow *window = new MainWindow();
   window->show();

   return app.exec();
}

